<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="119"/>
        <source>Sndfile Plugin</source>
        <translation>Engadido Sndfile</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="122"/>
        <source>PCM Files</source>
        <translation>Ficheiros PCM</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="225"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>Sobre o engadido Sndfile</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="226"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Engadido Sndfile de Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="227"/>
        <source>Compiled against</source>
        <translation>Compilado con</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="228"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
